==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/LINEARLOCATIONDETAILID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for LINEARLOCATIONDETAILID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="LINEARLOCATIONDETAILID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}CHECKLISTCODE"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}RELATEDWORKORDERID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}EVENTPOINTID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}DEFERREDMAINTENANCEID"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LINEARLOCATIONDETAILID_Type", propOrder = {
    "activityid",
    "checklistcode",
    "relatedworkorderid",
    "eventpointid",
    "deferredmaintenanceid"
})
public class LINEARLOCATIONDETAILID_Type {

    @XmlElement(name = "ACTIVITYID")
    protected ACTIVITYID activityid;
    @XmlElement(name = "CHECKLISTCODE")
    protected String checklistcode;
    @XmlElement(name = "RELATEDWORKORDERID")
    protected WOID_Type relatedworkorderid;
    @XmlElement(name = "EVENTPOINTID")
    protected EVENTPOINTID_Type eventpointid;
    @XmlElement(name = "DEFERREDMAINTENANCEID")
    protected DEFMID_Type deferredmaintenanceid;

    /**
     * Gets the value of the activityid property.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYID }
     *     
     */
    public ACTIVITYID getACTIVITYID() {
        return activityid;
    }

    /**
     * Sets the value of the activityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYID }
     *     
     */
    public void setACTIVITYID(ACTIVITYID value) {
        this.activityid = value;
    }

    /**
     * Gets the value of the checklistcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCHECKLISTCODE() {
        return checklistcode;
    }

    /**
     * Sets the value of the checklistcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCHECKLISTCODE(String value) {
        this.checklistcode = value;
    }

    /**
     * Gets the value of the relatedworkorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getRELATEDWORKORDERID() {
        return relatedworkorderid;
    }

    /**
     * Sets the value of the relatedworkorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setRELATEDWORKORDERID(WOID_Type value) {
        this.relatedworkorderid = value;
    }

    /**
     * Gets the value of the eventpointid property.
     * 
     * @return
     *     possible object is
     *     {@link EVENTPOINTID_Type }
     *     
     */
    public EVENTPOINTID_Type getEVENTPOINTID() {
        return eventpointid;
    }

    /**
     * Sets the value of the eventpointid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EVENTPOINTID_Type }
     *     
     */
    public void setEVENTPOINTID(EVENTPOINTID_Type value) {
        this.eventpointid = value;
    }

    /**
     * Gets the value of the deferredmaintenanceid property.
     * 
     * @return
     *     possible object is
     *     {@link DEFMID_Type }
     *     
     */
    public DEFMID_Type getDEFERREDMAINTENANCEID() {
        return deferredmaintenanceid;
    }

    /**
     * Sets the value of the deferredmaintenanceid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEFMID_Type }
     *     
     */
    public void setDEFERREDMAINTENANCEID(DEFMID_Type value) {
        this.deferredmaintenanceid = value;
    }

}

==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_fields/LINEARLOCATIONDETAILID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour LINEARLOCATIONDETAILID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="LINEARLOCATIONDETAILID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}CHECKLISTCODE"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}RELATEDWORKORDERID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}EVENTPOINTID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}DEFERREDMAINTENANCEID"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LINEARLOCATIONDETAILID_Type", propOrder = {
    "activityid",
    "checklistcode",
    "relatedworkorderid",
    "eventpointid",
    "deferredmaintenanceid"
})
public class LINEARLOCATIONDETAILID_Type {

    @XmlElement(name = "ACTIVITYID")
    protected ACTIVITYID activityid;
    @XmlElement(name = "CHECKLISTCODE")
    protected String checklistcode;
    @XmlElement(name = "RELATEDWORKORDERID")
    protected WOID_Type relatedworkorderid;
    @XmlElement(name = "EVENTPOINTID")
    protected EVENTPOINTID_Type eventpointid;
    @XmlElement(name = "DEFERREDMAINTENANCEID")
    protected DEFMID_Type deferredmaintenanceid;

    /**
     * Obtient la valeur de la propriété activityid.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYID }
     *     
     */
    public ACTIVITYID getACTIVITYID() {
        return activityid;
    }

    /**
     * Définit la valeur de la propriété activityid.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYID }
     *     
     */
    public void setACTIVITYID(ACTIVITYID value) {
        this.activityid = value;
    }

    /**
     * Obtient la valeur de la propriété checklistcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCHECKLISTCODE() {
        return checklistcode;
    }

    /**
     * Définit la valeur de la propriété checklistcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCHECKLISTCODE(String value) {
        this.checklistcode = value;
    }

    /**
     * Obtient la valeur de la propriété relatedworkorderid.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getRELATEDWORKORDERID() {
        return relatedworkorderid;
    }

    /**
     * Définit la valeur de la propriété relatedworkorderid.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setRELATEDWORKORDERID(WOID_Type value) {
        this.relatedworkorderid = value;
    }

    /**
     * Obtient la valeur de la propriété eventpointid.
     * 
     * @return
     *     possible object is
     *     {@link EVENTPOINTID_Type }
     *     
     */
    public EVENTPOINTID_Type getEVENTPOINTID() {
        return eventpointid;
    }

    /**
     * Définit la valeur de la propriété eventpointid.
     * 
     * @param value
     *     allowed object is
     *     {@link EVENTPOINTID_Type }
     *     
     */
    public void setEVENTPOINTID(EVENTPOINTID_Type value) {
        this.eventpointid = value;
    }

    /**
     * Obtient la valeur de la propriété deferredmaintenanceid.
     * 
     * @return
     *     possible object is
     *     {@link DEFMID_Type }
     *     
     */
    public DEFMID_Type getDEFERREDMAINTENANCEID() {
        return deferredmaintenanceid;
    }

    /**
     * Définit la valeur de la propriété deferredmaintenanceid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEFMID_Type }
     *     
     */
    public void setDEFERREDMAINTENANCEID(DEFMID_Type value) {
        this.deferredmaintenanceid = value;
    }

}
